"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const cli_utils_1 = require("@ionic/cli-utils");
const modules_1 = require("./lib/modules");
const arguments_1 = require("./utils/arguments");
const generate_1 = require("./utils/generate");
function generate(args) {
    return __awaiter(this, void 0, void 0, function* () {
        if (!args.env.project.directory) {
            return [];
        }
        const appScriptsArgs = arguments_1.minimistOptionsToArray(args.options);
        process.argv = ['node', 'appscripts'].concat(appScriptsArgs);
        const ionicInfo = yield cli_utils_1.readPackageJsonFile(path.resolve(args.env.project.directory, 'node_modules', 'ionic-angular', 'package.json'));
        if (Number(ionicInfo.version.charAt(0)) < 3) {
            throw new Error(`The generate command is only available for projects that use ionic-angular >= 3.0.0`);
        }
        const AppScripts = modules_1.load('@ionic/app-scripts');
        const context = AppScripts.generateContext();
        const [type, name] = args.inputs;
        switch (type) {
            case 'page':
                return yield AppScripts.processPageRequest(context, name);
            case 'component':
                const componentData = yield promptQuestions(context);
                return yield AppScripts.processComponentRequest(context, name, componentData);
            case 'directive':
                const directiveData = yield promptQuestions(context);
                return yield AppScripts.processDirectiveRequest(context, name, directiveData);
            case 'pipe':
                const pipeData = yield promptQuestions(context);
                return yield AppScripts.processPipeRequest(context, name, pipeData);
            case 'provider':
                const providerData = yield promptQuestions(context);
                return yield AppScripts.processProviderRequest(context, name, providerData);
            case 'tabs':
                const tabsData = yield tabsPromptQuestions();
                yield AppScripts.processTabsRequest(context, name, tabsData);
        }
        return [];
    });
}
exports.generate = generate;
function promptQuestions(context) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield generate_1.prompt(context);
    });
}
function tabsPromptQuestions() {
    return __awaiter(this, void 0, void 0, function* () {
        return yield generate_1.tabsPrompt();
    });
}
