"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk = require("chalk");
const cli_utils_1 = require("@ionic/cli-utils");
const modules_1 = require("./lib/modules");
const arguments_1 = require("./utils/arguments");
function serve(args) {
    return __awaiter(this, void 0, void 0, function* () {
        const availableIPs = cli_utils_1.getAvailableIPAddress();
        if (availableIPs.length === 0 && args.options.externalIpRequired) {
            throw new Error(`It appears that you do not have any external network interfaces. ` +
                `In order to use livereload with emulate you will need one.`);
        }
        let chosenIP = (availableIPs.length === 0) ? '0.0.0.0' : availableIPs[0].address;
        if (availableIPs.length > 1) {
            if (availableIPs.find(({ address }) => address === args.options.address)) {
                chosenIP = args.options.address;
            }
            else {
                const inquirer = modules_1.load('inquirer');
                const promptAnswers = yield inquirer.prompt({
                    type: 'list',
                    name: 'ip',
                    message: 'Multiple addresses available. Please select which address to use:',
                    choices: availableIPs.map(ip => ip.address)
                });
                chosenIP = promptAnswers['ip'];
            }
        }
        args.options.address = chosenIP;
        let appScriptsArgs = arguments_1.minimistOptionsToArray(args.options);
        process.argv = ['node', 'appscripts'].concat(appScriptsArgs);
        const AppScripts = modules_1.load('@ionic/app-scripts');
        const context = AppScripts.generateContext();
        console.log(`Starting app-scripts server: ${chalk.bold(appScriptsArgs.join(' '))}\n`);
        const settings = yield AppScripts.serve(context);
        if (!settings) {
            throw new Error(`app-scripts serve unexpectedly failed.`);
        }
        return Object.assign({ publicIp: chosenIP, protocol: 'http' }, settings);
    });
}
exports.serve = serve;
